@@ -7,10 +7,13 @@
 #include <libxml/parser.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
+#include <glib/goption.h>
 #include <string.h>
 #include <geoclue.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <clutter-gtk/clutter-gtk.h>
+#include <stdlib.h>
+#include <stdio.h>
 
 #include "gnome-voice-file.h"
 #include "gnome-voice-vosc.h"
@@ -28,6 +31,10 @@ GtkWidget *filename_entry;
 GtkWidget *filename_label;
 GtkWidget *summary_entry;
 GtkWidget *summary_label;
+gchar *voice_filename;
+gchar *voice_stream;
+
+VoiceInfo *voiceinfo;
 
 #define N_COLS 2
 #define COL_ID 0
@@ -160,6 +167,20 @@ static GOptionEntry entries[] =
              "Street = 6, "
              "Exact = 8."),
           "A" },
+	{ "filename",
+	  'f',
+	  0,
+	  G_OPTION_ARG_STRING,
+	  &voice_filename,
+	  N_("Filename.  Default: GNOME.voice"),
+	  "F" },
+	{ "stream",
+	  's',
+	  0,
+	  G_OPTION_ARG_STRING,
+	  &voice_stream,
+	  N_("Stream.  Default: https://api.perceptron.stream:8000/56.ogg"),
+	  "S" },
         { NULL }
 };
 
@@ -477,13 +498,13 @@ static void gv_wizard_cancel(GtkAssistant * assistant, gpointer data)
 static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 {
 	FILE *voice_pointer = NULL;
-	VoiceInfo *voiceinfo = (VoiceInfo *) data;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
 	gchar *filename_voice = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", "GNOME.voice", NULL);
 	gchar *string;
 	char buf[256];
 	GDate d;
 	const char *charset;
+        voiceinfo = (VoiceInfo *) data;
 
 	/* Version and current date. */
 	g_date_clear (&d, 1);
@@ -554,28 +575,44 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 0.6.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 0.7.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Title", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
 		{NULL, -1, "Complete", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},		
 	};
 	VoiceInfo *voinfo;
-	gchar *voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+	int entries_n = 2;
+	int entryNumber;
+	GError *error = NULL;
+	GOptionContext *context;
+
+	voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
 					    "GNOME.voice", NULL);
 	voinfo = gnome_voice_file_loader (voinfo,
 					  voice_filename);
-	g_free (voinfo);
 	// gtk_init(&argc, &argv);
+	if (argc < 2) {
+	  fprintf(stderr, "No Voice Stream typed on the command line\n");
+	}
+
+	context = g_option_context_new ("- Voice 0.7.0");
+	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	if (!g_option_context_parse (context, &argc, &argv, &error)) {
+	  g_print ("Voice Option parsing failed: %s\n", error->message);
+	  return EXIT_FAILURE;
+	}
+	g_free (voinfo);
 	gtk_clutter_init(&argc, &argv);
 	window = gtk_clutter_window_new ();
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.6.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 0.7.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 0.6.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 0.7.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Title:"));
 	title_entry = gtk_entry_new();
@@ -653,7 +690,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 0.6.0",
+				 GST_TAG_COMMENT, "Voice 0.7.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
@@ -727,10 +764,8 @@ main (gint argc, gchar **argv)
 	/* Create the voice player */
 	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
 	gst_player_set_uri (GST_PLAYER (player), voiceinfo->stream->uri);
-#if 0
-	gst_player_set_uri (GST_PLAYER (player), "http://api.perceptron.stream:8000/56.ogg");	
-#endif
-	gst_player_stop (GST_PLAYER (player));
+	gst_player_play(GST_PLAYER (player));
+	gst_player_set_uri (GST_PLAYER (player), voice_stream);
 	gst_player_play(GST_PLAYER (player));
 #if 0
         g_timeout_add (3600000, (GSourceFunc) on_simple_ready, &callback_data);
