@@ -6,8 +6,8 @@
 double lat = 21.293352;
 double lon = -157.839583;
 
-double lat_gps = 60.293352;
-double lon_gps = 10.839583;
+double lat_gps = 21.293352;
+double lon_gps = -157.839583;
 
 typedef struct
 {
